@@ -7,14 +7,14 @@ class System:
         pass
 
     def disk_available(self, disk):
-        return self.run('blkid {}'.format(disk))
+        return self.run(['blkid', disk])
 
     def mount_disk(self, disk, directory):
-        return self.run('mount {} {}'.format(disk, directory))
+        return self.run(['mount', disk, directory])
 
     def fix_permissions(self, directory, user):
-        chmod = 'chmod  770 {}'.format(directory)
-        chown = 'chown -R {}:{} {}'.format(user, user, directory)
+        chmod = ['chmod', '770', directory]
+        chown = ['chown', '-R', '{}:{}'.format(user, user), directory]
         return self.run(chmod) and self.run(chown)
 
     def network_is_up(self):
@@ -22,11 +22,11 @@ class System:
             return f.read() == 'up'
 
     def sync_time(self):
-        return self.run('ntpdate -u pool.ntp.org')
+        return self.run(['ntpdate', '-u', 'pool.ntp.org'])
 
-    def run(self, command):
+    def run(self, *args):
         try:
-            print check_output(command.split(' '))
+            print check_output(*args)
             return True
         except Exception as e:
             print e.message
