@@ -12,7 +12,7 @@ class TestSystem(unittest.TestCase):
 
     def test_run_ok_with_args(self):
         system = System()
-        self.assertTrue(system.run('date -u'))
+        self.assertTrue(system.run(['date', '-u']))
 
     def test_run_fail(self):
         system = System()
